# Changelog

## 1.0.0 (2025-05-13)

Full Changelog: [v0.1.0-alpha.3...v1.0.0](https://github.com/carbon-aware/scheduler-client-python/compare/v0.1.0-alpha.3...v1.0.0)

### Features

* **api:** api update ([e37c8c7](https://github.com/carbon-aware/scheduler-client-python/commit/e37c8c7ff4188178fed280f3f3cddd203171f85f))
* **api:** api update ([553bd3a](https://github.com/carbon-aware/scheduler-client-python/commit/553bd3a9000c5a6fc3672aff45b46064ab4a6f9d))

## 0.1.0-alpha.3 (2025-05-13)

Full Changelog: [v0.1.0-alpha.2...v0.1.0-alpha.3](https://github.com/carbon-aware/scheduler-client-python/compare/v0.1.0-alpha.2...v0.1.0-alpha.3)

### Features

* **api:** manual updates ([7c17d97](https://github.com/carbon-aware/scheduler-client-python/commit/7c17d972bf19e232b7a900b82625d2c79258a9ea))

## 0.1.0-alpha.2 (2025-05-13)

Full Changelog: [v0.1.0-alpha.1...v0.1.0-alpha.2](https://github.com/carbon-aware/scheduler-client-python/compare/v0.1.0-alpha.1...v0.1.0-alpha.2)

### Features

* manual updates ([6120e46](https://github.com/carbon-aware/scheduler-client-python/commit/6120e46e32425d30b865eec44375cabe539a4376))

## 0.1.0-alpha.1 (2025-05-13)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/carbon-aware/scheduler-client-python/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** update via SDK Studio ([91b694b](https://github.com/carbon-aware/scheduler-client-python/commit/91b694bc08bb27d58f26e8b6c80276d6cba58972))
* **api:** update via SDK Studio ([031c768](https://github.com/carbon-aware/scheduler-client-python/commit/031c768a27d9e8beb8f9ed8b2debe49cb3abc391))
* **api:** update via SDK Studio ([a37522d](https://github.com/carbon-aware/scheduler-client-python/commit/a37522dd9f8d0cb6b173d8870aa11bb4d1acd416))


### Chores

* update SDK settings ([4deddd9](https://github.com/carbon-aware/scheduler-client-python/commit/4deddd9c02afd6e78eea9eec9ac092f3b2dc763a))
* update SDK settings ([080c945](https://github.com/carbon-aware/scheduler-client-python/commit/080c945a3cb28ab6741b9eecf009bc972ea2704a))
